@@ -1,4 +1,6 @@
+"""Differentiable and gpu enabled fast wavelet transforms in PyTorch."""
+from .continuous_transform import cwt
 from .conv_transform import wavedec, wavedec2, waverec, waverec2
 from .matmul_transform import MatrixWavedec, MatrixWaverec
-from .matmul_transform_2d import MatrixWavedec2d, MatrixWaverec2d
+from .matmul_transform_2 import MatrixWavedec2, MatrixWaverec2
 from .packets import WaveletPacket, WaveletPacket2D
