@@ -53,7 +53,7 @@ def get_filter_tensors(
     return dec_lo_tensor, dec_hi_tensor, rec_lo_tensor, rec_hi_tensor
 
 
-def get_pad(data_len: int, filt_len: int) -> Tuple[int, int]:
+def _get_pad(data_len: int, filt_len: int) -> Tuple[int, int]:
     """Compute the required padding.
 
     Args:
@@ -87,6 +87,30 @@ def get_pad(data_len: int, filt_len: int) -> Tuple[int, int]:
     return padr, padl
 
 
+def _translate_boundary_strings(pywt_mode: str) -> str:
+    """Translate pywt mode strings to pytorch mode strings.
+
+    We support constant, zero, reflect and periodic.
+    Unfortunately "constant" has different meanings in the
+    pytorch and pywavelet communities.
+
+    Raises:
+        ValueError: If the padding mode is not supported.
+
+    """
+    if pywt_mode == "constant":
+        pt_mode = "replicate"
+    elif pywt_mode == "zero":
+        pt_mode = "constant"
+    elif pywt_mode == "reflect":
+        pt_mode = pywt_mode
+    elif pywt_mode == "periodic":
+        pt_mode = "circular"
+    else:
+        raise ValueError("Padding mode not supported.")
+    return pt_mode
+
+
 def fwt_pad(
     data: torch.Tensor, wavelet: Union[Wavelet, str], mode: str = "reflect"
 ) -> torch.Tensor:
@@ -97,23 +121,28 @@ def fwt_pad(
         wavelet (Wavelet or str): A pywt wavelet compatible object or
             the name of a pywt wavelet.
         mode (str): The desired way to pad.
+            Supported modes are "reflect", "zero", "constant" and "periodic".
+            Refection padding mirrors samples along the border.
+            Zero padding pads zeros.
+            Constant padding replicates border values.
+            periodic padding repeats samples in a cyclic fashing.
+            Defaults to reflect.
 
     Returns:
         torch.Tensor: A pytorch tensor with the padded input data
 
     """
     wavelet = _as_wavelet(wavelet)
-    if mode == "zero":
-        # convert pywt to pytorch convention.
-        mode = "constant"
+    # convert pywt to pytorch convention.
+    mode = _translate_boundary_strings(mode)
 
-    padr, padl = get_pad(data.shape[-1], len(wavelet.dec_lo))
+    padr, padl = _get_pad(data.shape[-1], len(wavelet.dec_lo))
     data_pad = torch.nn.functional.pad(data, [padl, padr], mode=mode)
     return data_pad
 
 
-def fwt_pad2d(
-    data: torch.Tensor, wavelet: Union[Wavelet, str], level: int, mode: str = "reflect"
+def fwt_pad2(
+    data: torch.Tensor, wavelet: Union[Wavelet, str], mode: str = "reflect"
 ) -> torch.Tensor:
     """Pad data for the 2d FWT.
 
@@ -121,16 +150,19 @@ def fwt_pad2d(
         data (torch.Tensor): Input data with 4 dimensions.
         wavelet (Wavelet or str): A pywt wavelet compatible object or
             the name of a pywt wavelet.
-        level (int): The number of scales in the transform.
-        mode (str): The padding mode. Defaults to 'reflect'.
+        mode (str): The padding mode.
+            Supported modes are "reflect", "zero", "constant" and "periodic".
+            Defaults to reflect.
 
     Returns:
         The padded output tensor.
 
     """
+    mode = _translate_boundary_strings(mode)
+
     wavelet = _as_wavelet(wavelet)
-    padb, padt = get_pad(data.shape[-2], len(wavelet.dec_lo))
-    padr, padl = get_pad(data.shape[-1], len(wavelet.dec_lo))
+    padb, padt = _get_pad(data.shape[-2], len(wavelet.dec_lo))
+    padr, padl = _get_pad(data.shape[-1], len(wavelet.dec_lo))
     data_pad = torch.nn.functional.pad(data, [padl, padr, padt, padb], mode=mode)
     return data_pad
 
@@ -144,7 +176,7 @@ def _outer(a: torch.Tensor, b: torch.Tensor) -> torch.Tensor:
     return a_mul * b_mul
 
 
-def flatten_2d_coeff_lst(
+def _flatten_2d_coeff_lst(
     coeff_lst_2d: List[
         Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor, torch.Tensor]]
     ],
@@ -185,6 +217,7 @@ def construct_2d_filt(lo: torch.Tensor, hi: torch.Tensor) -> torch.Tensor:
     Returns:
         torch.Tensor: Stacked 2d filters of dimension
             [filt_no, 1, height, width].
+            The four filters are ordered ll, lh, hl, hh.
 
     """
     ll = _outer(lo, lo)
@@ -207,12 +240,15 @@ def wavedec2(
     Args:
         data (torch.Tensor): The input data tensor of shape
             [batch_size, 1, height, width].
+            2d inputs are interpreted as [height, width],
+            3d inputs are interpreted as [batch_size, height, width].
         wavelet (Wavelet or str): A pywt wavelet compatible object or
-                the name of a pywt wavelet.
+            the name of a pywt wavelet.
         level (int): The number of desired scales.
             Defaults to None.
-        mode (str): The padding mode, i.e. zero or reflect.
-            Defaults to reflect.
+        mode (str): The padding mode. Options are
+            "reflect", "zero", "constant" and "periodic".
+            Defaults to "reflect".
 
     Returns:
         list: A list containing the wavelet coefficients.
@@ -230,9 +266,14 @@ def wavedec2(
                                 [2, 0, 1]).astype(np.float64)
         >>> pytorch_face = torch.tensor(face).unsqueeze(1)
         >>> coefficients = ptwt.wavedec2(pytorch_face, pywt.Wavelet("haar"),
-                                         level=2, mode="constant")
+                                         level=2, mode="zero")
 
     """
+    if data.dim() == 2:
+        data = data.unsqueeze(0).unsqueeze(0)
+    elif data.dim() == 3:
+        data = data.unsqueeze(1)
+
     wavelet = _as_wavelet(wavelet)
     dec_lo, dec_hi, _, _ = get_filter_tensors(
         wavelet, flip=True, device=data.device, dtype=data.dtype
@@ -246,8 +287,8 @@ def wavedec2(
         Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor, torch.Tensor]]
     ] = []
     res_ll = data
-    for s in range(level):
-        res_ll = fwt_pad2d(res_ll, wavelet, level=s, mode=mode)
+    for _ in range(level):
+        res_ll = fwt_pad2(res_ll, wavelet, mode=mode)
         res = torch.nn.functional.conv2d(res_ll, dec_filt, stride=2)
         res_ll, res_lh, res_hl, res_hh = torch.split(res, 1, 1)
         result_lst.append((res_lh, res_hl, res_hh))
@@ -353,8 +394,9 @@ def wavedec(
             the name of a pywt wavelet.
         level (int): The scale level to be computed.
                                Defaults to None.
-        mode (str): The padding mode i.e. zero or reflect.
-                              Defaults to reflect.
+        mode (str): The desired padding mode. Padding extends the singal along
+            the edges. Supported modes are "reflect", "zero", "constant"
+            and "periodic". Defaults to "reflect".
 
     Returns:
         list: A list [cA_n, cD_n, cD_n-1, …, cD2, cD1]
@@ -373,10 +415,10 @@ def wavedec(
                          mode='zero', level=2)
 
     """
-    if len(data.shape) == 1:
+    if data.dim() == 1:
         # assume time series
         data = data.unsqueeze(0).unsqueeze(0)
-    elif len(data.shape) == 2:
+    elif data.dim() == 2:
         # assume batched time series
         data = data.unsqueeze(1)
 
